==> 0.0.2+4.tar.gz: lib/shared/helper/date_helper.dart <==
import 'package:easy_localization/easy_localization.dart';
import 'package:intl/date_symbol_data_local.dart';

class DateHelper {
  static dateFormat({String? date, String? locale}) {
    try {
      if (date?.isNotEmpty == true) {
        var time = date?.split("+");
        initializeDateFormatting("vi_VN");
        var inputFormat =
            DateFormat("yyyy-MM-dd'T'HH:mm:ss", locale ?? "vi_VN");
        var inputDate = inputFormat.parse(time![0]);
        var outputFormat =
            DateFormat('hh:mm a - dd/MM/yyyy', locale ?? "vi_VN");
        var outputDate = outputFormat.format(inputDate);
        return outputDate.toUpperCase();
      } else {
        return "text_no_update".tr();
      }
    } catch (e) {
      return "format error";
    }
  }

  static String dateFormatDatetime({required DateTime? time, String? content}) {
    if (time != null) {
      return DateFormat('hh:mm a').format(time);
    } else {
      return "$content";
    }
  }

  static dateDefaultFormat({String? date, String? locale}) {
    try {
      if (date?.isNotEmpty == true) {
        var time = date?.split("+");
        initializeDateFormatting(locale ?? "vi_VN");
        var inputFormat =
            DateFormat("yyyy-MM-dd'T'HH:mm:ss", locale ?? "vi_VN");
        var inputDate = inputFormat.parse(time![0]);
        var outputFormat = DateFormat('dd/MM/yyyy', locale ?? "vi_VN");
        var outputDate = outputFormat.format(inputDate);
        return outputDate.toUpperCase();
      } else {
        return "text_no_update".tr();
      }
    } catch (e) {
      return "format error";
    }
  }

  static dateCustom2Format({String? date, String? locale}) {
    try {
      if (date?.isNotEmpty == true) {
        var time = date?.split("+");
        initializeDateFormatting(locale ?? "vi_VN");
        var inputFormat =
            DateFormat("yyyy-MM-dd'T'HH:mm:ss", locale ?? "vi_VN");
        var inputDate = inputFormat.parse(time![0]);
        var outputFormat = DateFormat('dd/MM/yyyy, hh:mm a', locale ?? "vi_VN");
        var outputDate = outputFormat.format(inputDate);
        return outputDate.toUpperCase();
      } else {
        return "text_no_update".tr();
      }
    } catch (e) {
      return "format error";
    }
  }
}

==> 0.0.3+11.tar.gz: lib/shared/helper/date_helper.dart <==
import 'package:easy_localization/easy_localization.dart';
import 'package:intl/date_symbol_data_local.dart';

class DateHelper {
  static dateFormat({String? date, String? locale}) {
    try {
      if (date?.isNotEmpty == true) {
        var time = date?.split("+");
        initializeDateFormatting("vi_VN");
        var inputFormat =
            DateFormat("yyyy-MM-dd'T'HH:mm:ss", locale ?? "vi_VN");
        var inputDate = inputFormat.parse(time![0]);
        var outputFormat =
            DateFormat('hh:mm a - dd/MM/yyyy', locale ?? "vi_VN");
        var outputDate = outputFormat.format(inputDate);
        return outputDate.toUpperCase();
      } else {
        return "text_no_update".tr();
      }
    } catch (e) {
      return "format error";
    }
  }

  static String dateFormatDatetime({required String? date, String? content}) {
    try {
      if (date?.isNotEmpty == true) {
        var time = date?.split("+");
        initializeDateFormatting("vi_VN");
        var inputFormat =
            DateFormat("yyyy-MM-dd'T'HH:mm:ss", "vi_VN");
        var inputDate = inputFormat.parse(time![0]);
        var outputFormat = DateFormat('hh:mm a', "vi_VN");
        var outputDate = outputFormat.format(inputDate);
        return outputDate.toUpperCase();
      } else {
        return "$content";
      }
    } catch (e) {
      return "$content";
    }
  }

  static dateDefaultFormat({String? date, String? locale}) {
    try {
      if (date?.isNotEmpty == true) {
        var time = date?.split("+");
        initializeDateFormatting(locale ?? "vi_VN");
        var inputFormat =
            DateFormat("yyyy-MM-dd'T'HH:mm:ss", locale ?? "vi_VN");
        var inputDate = inputFormat.parse(time![0]);
        var outputFormat = DateFormat('dd/MM/yyyy', locale ?? "vi_VN");
        var outputDate = outputFormat.format(inputDate);
        return outputDate.toUpperCase();
      } else {
        return "text_no_update".tr();
      }
    } catch (e) {
      return "format error";
    }
  }

  static dateCustom2Format({String? date, String? locale}) {
    try {
      if (date?.isNotEmpty == true) {
        var time = date?.split("+");
        initializeDateFormatting(locale ?? "vi_VN");
        var inputFormat =
            DateFormat("yyyy-MM-dd'T'HH:mm:ss", locale ?? "vi_VN");
        var inputDate = inputFormat.parse(time![0]);
        var outputFormat = DateFormat('dd/MM/yyyy, hh:mm a', locale ?? "vi_VN");
        var outputDate = outputFormat.format(inputDate);
        return outputDate.toUpperCase();
      } else {
        return "text_no_update".tr();
      }
    } catch (e) {
      return "format error";
    }
  }
}
